# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/reporting/income_report/v1/entry.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/reporting/income_report/v1/entry.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from meshtrade.type.v1 import token_pb2 as meshtrade_dot_type_dot_v1_dot_token__pb2
from meshtrade.type.v1 import amount_pb2 as meshtrade_dot_type_dot_v1_dot_amount__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0meshtrade/reporting/income_report/v1/entry.proto\x12$meshtrade.reporting.income_report.v1\x1a\x1dmeshtrade/type/v1/token.proto\x1a\x1emeshtrade/type/v1/amount.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xfd\x02\n\x05\x45ntry\x12\x1d\n\nasset_name\x18\x01 \x01(\tR\tassetName\x12.\n\x05token\x18\x02 \x01(\x0b\x32\x18.meshtrade.type.v1.TokenR\x05token\x12.\n\x04\x64\x61te\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x04\x64\x61te\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription\x12M\n\tnarrative\x18\x05 \x01(\x0e\x32/.meshtrade.reporting.income_report.v1.NarrativeR\tnarrative\x12\x31\n\x06\x61mount\x18\x06 \x01(\x0b\x32\x19.meshtrade.type.v1.AmountR\x06\x61mount\x12Q\n\x17reported_currency_value\x18\x07 \x01(\x0b\x32\x19.meshtrade.type.v1.AmountR\x15reportedCurrencyValue*Q\n\tNarrative\x12\x19\n\x15NARRATIVE_UNSPECIFIED\x10\x00\x12\x13\n\x0fNARRATIVE_YIELD\x10\x01\x12\x14\n\x10NARRATIVE_COUPON\x10\x02\x42u\n+co.meshtrade.api.reporting.income_report.v1ZFgithub.com/meshtrade/api/go/reporting/income_report/v1;income_reportv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.reporting.income_report.v1.entry_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+co.meshtrade.api.reporting.income_report.v1ZFgithub.com/meshtrade/api/go/reporting/income_report/v1;income_reportv1'
  _globals['_NARRATIVE']._serialized_start=570
  _globals['_NARRATIVE']._serialized_end=651
  _globals['_ENTRY']._serialized_start=187
  _globals['_ENTRY']._serialized_end=568
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from meshtrade.reporting.income_report.v1 import income_report_pb2 as meshtrade_dot_reporting_dot_income__report_dot_v1_dot_income__report__pb2
from meshtrade.reporting.income_report.v1 import service_pb2 as meshtrade_dot_reporting_dot_income__report_dot_v1_dot_service__pb2


class IncomeReportServiceStub(object):
    """
    IncomeReportService manages income report generation and export.

    This service allows clients to retrieve structured income reports
    and download them as Excel files. Reports are generated for a
    specified account over a given time range and denominated in
    a selected reporting currency.

    All operations require access to financial reporting permissions.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetIncomeReport = channel.unary_unary(
                '/meshtrade.reporting.income_report.v1.IncomeReportService/GetIncomeReport',
                request_serializer=meshtrade_dot_reporting_dot_income__report_dot_v1_dot_service__pb2.GetIncomeReportRequest.SerializeToString,
                response_deserializer=meshtrade_dot_reporting_dot_income__report_dot_v1_dot_income__report__pb2.IncomeReport.FromString,
                _registered_method=True)
        self.GetExcelIncomeReport = channel.unary_unary(
                '/meshtrade.reporting.income_report.v1.IncomeReportService/GetExcelIncomeReport',
                request_serializer=meshtrade_dot_reporting_dot_income__report_dot_v1_dot_service__pb2.GetExcelIncomeReportRequest.SerializeToString,
                response_deserializer=meshtrade_dot_reporting_dot_income__report_dot_v1_dot_service__pb2.GetExcelIncomeReportResponse.FromString,
                _registered_method=True)


class IncomeReportServiceServicer(object):
    """
    IncomeReportService manages income report generation and export.

    This service allows clients to retrieve structured income reports
    and download them as Excel files. Reports are generated for a
    specified account over a given time range and denominated in
    a selected reporting currency.

    All operations require access to financial reporting permissions.
    """

    def GetIncomeReport(self, request, context):
        """
        Retrieves a structured income report for a specific account and time range.

        Parameters:
        - account_num: Unique account identifier
        - from: Start timestamp for the report period
        - to: End timestamp for the report period
        - reporting_currency_token: Token in which report values are denominated

        Returns:
        - GetIncomeReportResponse: Structured income report with earnings breakdown
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExcelIncomeReport(self, request, context):
        """
        Exports an income report to Excel format for download.

        Parameters:
        - account_num: Unique account identifier
        - from: Start timestamp for the report period
        - to: End timestamp for the report period
        - reporting_currency_token: Token in which report values are denominated

        Returns:
        - GetExcelIncomeReportResponse: Base64-encoded Excel file containing the report
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_IncomeReportServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetIncomeReport': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIncomeReport,
                    request_deserializer=meshtrade_dot_reporting_dot_income__report_dot_v1_dot_service__pb2.GetIncomeReportRequest.FromString,
                    response_serializer=meshtrade_dot_reporting_dot_income__report_dot_v1_dot_income__report__pb2.IncomeReport.SerializeToString,
            ),
            'GetExcelIncomeReport': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExcelIncomeReport,
                    request_deserializer=meshtrade_dot_reporting_dot_income__report_dot_v1_dot_service__pb2.GetExcelIncomeReportRequest.FromString,
                    response_serializer=meshtrade_dot_reporting_dot_income__report_dot_v1_dot_service__pb2.GetExcelIncomeReportResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'meshtrade.reporting.income_report.v1.IncomeReportService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('meshtrade.reporting.income_report.v1.IncomeReportService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class IncomeReportService(object):
    """
    IncomeReportService manages income report generation and export.

    This service allows clients to retrieve structured income reports
    and download them as Excel files. Reports are generated for a
    specified account over a given time range and denominated in
    a selected reporting currency.

    All operations require access to financial reporting permissions.
    """

    @staticmethod
    def GetIncomeReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.reporting.income_report.v1.IncomeReportService/GetIncomeReport',
            meshtrade_dot_reporting_dot_income__report_dot_v1_dot_service__pb2.GetIncomeReportRequest.SerializeToString,
            meshtrade_dot_reporting_dot_income__report_dot_v1_dot_income__report__pb2.IncomeReport.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetExcelIncomeReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/meshtrade.reporting.income_report.v1.IncomeReportService/GetExcelIncomeReport',
            meshtrade_dot_reporting_dot_income__report_dot_v1_dot_service__pb2.GetExcelIncomeReportRequest.SerializeToString,
            meshtrade_dot_reporting_dot_income__report_dot_v1_dot_service__pb2.GetExcelIncomeReportResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



import datetime

from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from meshtrade.reporting.income_report.v1 import income_report_pb2 as _income_report_pb2
from meshtrade.iam.role.v1 import role_pb2 as _role_pb2
from meshtrade.option.v1 import method_type_pb2 as _method_type_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetIncomeReportRequest(_message.Message):
    __slots__ = ("account_num", "to")
    ACCOUNT_NUM_FIELD_NUMBER: _ClassVar[int]
    FROM_FIELD_NUMBER: _ClassVar[int]
    TO_FIELD_NUMBER: _ClassVar[int]
    account_num: str
    to: _timestamp_pb2.Timestamp
    def __init__(self, account_num: _Optional[str] = ..., to: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., **kwargs) -> None: ...

class GetExcelIncomeReportRequest(_message.Message):
    __slots__ = ("account_num", "to")
    ACCOUNT_NUM_FIELD_NUMBER: _ClassVar[int]
    FROM_FIELD_NUMBER: _ClassVar[int]
    TO_FIELD_NUMBER: _ClassVar[int]
    account_num: str
    to: _timestamp_pb2.Timestamp
    def __init__(self, account_num: _Optional[str] = ..., to: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., **kwargs) -> None: ...

class GetExcelIncomeReportResponse(_message.Message):
    __slots__ = ("excel_base64",)
    EXCEL_BASE64_FIELD_NUMBER: _ClassVar[int]
    excel_base64: str
    def __init__(self, excel_base64: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/reporting/income_report/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/reporting/income_report/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from meshtrade.reporting.income_report.v1 import income_report_pb2 as meshtrade_dot_reporting_dot_income__report_dot_v1_dot_income__report__pb2
from meshtrade.iam.role.v1 import role_pb2 as meshtrade_dot_iam_dot_role_dot_v1_dot_role__pb2
from meshtrade.option.v1 import method_type_pb2 as meshtrade_dot_option_dot_v1_dot_method__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2meshtrade/reporting/income_report/v1/service.proto\x12$meshtrade.reporting.income_report.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x38meshtrade/reporting/income_report/v1/income_report.proto\x1a meshtrade/iam/role/v1/role.proto\x1a%meshtrade/option/v1/method_type.proto\"\x95\x01\n\x16GetIncomeReportRequest\x12\x1f\n\x0b\x61\x63\x63ount_num\x18\x01 \x01(\tR\naccountNum\x12.\n\x04\x66rom\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x04\x66rom\x12*\n\x02to\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x02to\"\x82\x03\n\x1bGetExcelIncomeReportRequest\x12\x84\x01\n\x0b\x61\x63\x63ount_num\x18\x01 \x01(\tBc\xbaH`r\x0f\x10\x01\x32\x0b^[0-9]{1,}$\xba\x01L\n\x14\x61\x63\x63ount_num.required\x12\x17\x61\x63\x63ount_num is required\x1a\x1bthis.matches(\'^[0-9]{1,}$\')R\naccountNum\x12q\n\x04\x66rom\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampBA\xbaH>\xba\x01;\n\rfrom.required\x12\x1c\'from\' timestamp is required\x1a\x0cthis != nullR\x04\x66rom\x12i\n\x02to\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB=\xbaH:\xba\x01\x37\n\x0bto.required\x12\x1a\'to\' timestamp is required\x1a\x0cthis != nullR\x02to\"A\n\x1cGetExcelIncomeReportResponse\x12!\n\x0c\x65xcel_base64\x18\x01 \x01(\tR\x0b\x65xcelBase642\xdb\x02\n\x13IncomeReportService\x12\x93\x01\n\x0fGetIncomeReport\x12<.meshtrade.reporting.income_report.v1.GetIncomeReportRequest\x1a\x32.meshtrade.reporting.income_report.v1.IncomeReport\"\x0e\xa0\xb5\x18\x01\xaa\xb5\x18\x06\n\x04\x81\x9b\xee\x02\x12\xad\x01\n\x14GetExcelIncomeReport\x12\x41.meshtrade.reporting.income_report.v1.GetExcelIncomeReportRequest\x1a\x42.meshtrade.reporting.income_report.v1.GetExcelIncomeReportResponse\"\x0e\xa0\xb5\x18\x01\xaa\xb5\x18\x06\n\x04\x81\x9b\xee\x02\x42u\n+co.meshtrade.api.reporting.income_report.v1ZFgithub.com/meshtrade/api/go/reporting/income_report/v1;income_reportv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.reporting.income_report.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+co.meshtrade.api.reporting.income_report.v1ZFgithub.com/meshtrade/api/go/reporting/income_report/v1;income_reportv1'
  _globals['_GETEXCELINCOMEREPORTREQUEST'].fields_by_name['account_num']._loaded_options = None
  _globals['_GETEXCELINCOMEREPORTREQUEST'].fields_by_name['account_num']._serialized_options = b'\272H`r\017\020\0012\013^[0-9]{1,}$\272\001L\n\024account_num.required\022\027account_num is required\032\033this.matches(\'^[0-9]{1,}$\')'
  _globals['_GETEXCELINCOMEREPORTREQUEST'].fields_by_name['from']._loaded_options = None
  _globals['_GETEXCELINCOMEREPORTREQUEST'].fields_by_name['from']._serialized_options = b'\272H>\272\001;\n\rfrom.required\022\034\'from\' timestamp is required\032\014this != null'
  _globals['_GETEXCELINCOMEREPORTREQUEST'].fields_by_name['to']._loaded_options = None
  _globals['_GETEXCELINCOMEREPORTREQUEST'].fields_by_name['to']._serialized_options = b'\272H:\272\0017\n\013to.required\022\032\'to\' timestamp is required\032\014this != null'
  _globals['_INCOMEREPORTSERVICE'].methods_by_name['GetIncomeReport']._loaded_options = None
  _globals['_INCOMEREPORTSERVICE'].methods_by_name['GetIncomeReport']._serialized_options = b'\240\265\030\001\252\265\030\006\n\004\201\233\356\002'
  _globals['_INCOMEREPORTSERVICE'].methods_by_name['GetExcelIncomeReport']._loaded_options = None
  _globals['_INCOMEREPORTSERVICE'].methods_by_name['GetExcelIncomeReport']._serialized_options = b'\240\265\030\001\252\265\030\006\n\004\201\233\356\002'
  _globals['_GETINCOMEREPORTREQUEST']._serialized_start=286
  _globals['_GETINCOMEREPORTREQUEST']._serialized_end=435
  _globals['_GETEXCELINCOMEREPORTREQUEST']._serialized_start=438
  _globals['_GETEXCELINCOMEREPORTREQUEST']._serialized_end=824
  _globals['_GETEXCELINCOMEREPORTRESPONSE']._serialized_start=826
  _globals['_GETEXCELINCOMEREPORTRESPONSE']._serialized_end=891
  _globals['_INCOMEREPORTSERVICE']._serialized_start=894
  _globals['_INCOMEREPORTSERVICE']._serialized_end=1241
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/reporting/income_report/v1/income_report.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/reporting/income_report/v1/income_report.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from meshtrade.type.v1 import token_pb2 as meshtrade_dot_type_dot_v1_dot_token__pb2
from meshtrade.type.v1 import address_pb2 as meshtrade_dot_type_dot_v1_dot_address__pb2
from meshtrade.reporting.income_report.v1 import disclaimer_pb2 as meshtrade_dot_reporting_dot_income__report_dot_v1_dot_disclaimer__pb2
from meshtrade.reporting.income_report.v1 import entry_pb2 as meshtrade_dot_reporting_dot_income__report_dot_v1_dot_entry__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8meshtrade/reporting/income_report/v1/income_report.proto\x12$meshtrade.reporting.income_report.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dmeshtrade/type/v1/token.proto\x1a\x1fmeshtrade/type/v1/address.proto\x1a\x35meshtrade/reporting/income_report/v1/disclaimer.proto\x1a\x30meshtrade/reporting/income_report/v1/entry.proto\"\x99\x05\n\x0cIncomeReport\x12\x45\n\x07\x65ntries\x18\x01 \x03(\x0b\x32+.meshtrade.reporting.income_report.v1.EntryR\x07\x65ntries\x12G\n\x12reporting_currency\x18\x02 \x01(\x0b\x32\x18.meshtrade.type.v1.TokenR\x11reportingCurrency\x12Q\n\x06period\x18\x03 \x01(\x0b\x32\x39.meshtrade.reporting.income_report.v1.IncomeReport.PeriodR\x06period\x12\x43\n\x0fgeneration_date\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0egenerationDate\x12%\n\x0e\x61\x63\x63ount_number\x18\x05 \x01(\tR\raccountNumber\x12R\n\x0b\x64isclaimers\x18\x06 \x03(\x0b\x32\x30.meshtrade.reporting.income_report.v1.DisclaimerR\x0b\x64isclaimers\x12\x41\n\x0e\x63lient_address\x18\x07 \x01(\x0b\x32\x1a.meshtrade.type.v1.AddressR\rclientAddress\x12\x1f\n\x0b\x63lient_name\x18\x08 \x01(\tR\nclientName\x12\x1c\n\tcopyright\x18\t \x01(\tR\tcopyright\x1a\x64\n\x06Period\x12.\n\x04\x66rom\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x04\x66rom\x12*\n\x02to\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x02toBu\n+co.meshtrade.api.reporting.income_report.v1ZFgithub.com/meshtrade/api/go/reporting/income_report/v1;income_reportv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.reporting.income_report.v1.income_report_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+co.meshtrade.api.reporting.income_report.v1ZFgithub.com/meshtrade/api/go/reporting/income_report/v1;income_reportv1'
  _globals['_INCOMEREPORT']._serialized_start=301
  _globals['_INCOMEREPORT']._serialized_end=966
  _globals['_INCOMEREPORT_PERIOD']._serialized_start=866
  _globals['_INCOMEREPORT_PERIOD']._serialized_end=966
# @@protoc_insertion_point(module_scope)
